==> bidmad_flutter_plugin-1.5.1.tar.gz: lib/FlutterBaseInterstitial.dart <==
import 'package:flutter/services.dart';

class FlutterBaseInterstitial {
  late String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback;
  var onShowAdCallback;
  var onFailAdCallback;
  var onCloseAdCallback;

  FlutterBaseInterstitial({
    required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> load() async {
    await _platform.invokeMethod('load');
  }

  Future<void> show() async {
    await _platform.invokeMethod('show');
  }

  Future<bool> isLoaded() async {
    return await _platform.invokeMethod('isLoaded');
  }

  Future<void> setAdInfo(String zoneId) async {
    await _platform.invokeMethod('makeInterstitial', {"zoneId":zoneId});
  }

  Future<void> setCallbackListener({
    void Function()? onLoadAd,
    void Function()? onShowAd,
    void Function(String errorMsg)? onFailAd,
    void Function()? onCloseAd
  }) async {

    if(onLoadAd != null){
      onLoadAdCallback = onLoadAd;
    }
    if(onShowAd != null){
      onShowAdCallback = onShowAd;
    }
    if(onFailAd != null){
      onFailAdCallback = onFailAd;
    }
    if(onCloseAd != null){
      onCloseAdCallback = onCloseAd;
    }
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    switch (call.method) {
      case 'onLoadAd':
        if (onLoadAdCallback != null) {
          onLoadAdCallback();
        };
        break;
      case 'onShowAd':
        if (onShowAdCallback != null) {
          onShowAdCallback();
        };
        break;
      case 'onFailAd':
        String errorMessage = call.arguments.toString();
        if (onFailAdCallback != null) {
          onFailAdCallback(errorMessage);
        };
        break;
      case 'onCloseAd':
        if (onCloseAdCallback != null) {
          onCloseAdCallback();
        };
        break;
      default:
        throw ('method not defined');
    }
  }
}

==> bidmad_flutter_plugin-1.7.2.tar.gz: lib/FlutterBaseInterstitial.dart <==
import 'package:flutter/services.dart';

class FlutterBaseInterstitial {
  late String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback;
  var onShowAdCallback;
  var onFailAdCallback;
  var onCloseAdCallback;

  FlutterBaseInterstitial({
    required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> load() async {
    return await _platform.invokeMethod('load');
  }

  Future<void> show() async {
    return await _platform.invokeMethod('show');
  }

  Future<bool> isLoaded() async {
    return await _platform.invokeMethod('isLoaded');
  }

  Future<void> setAdInfo(String zoneId) async {
    return await _platform.invokeMethod('makeInterstitial', {"zoneId": zoneId});
  }

  Future<void> setCallbackListener({
    void Function()? onLoadAd,
    void Function()? onShowAd,
    void Function(String errorMsg)? onFailAd,
    void Function()? onCloseAd
  }) async {

    if(onLoadAd != null){
      onLoadAdCallback = onLoadAd;
    }
    if(onShowAd != null){
      onShowAdCallback = onShowAd;
    }
    if(onFailAd != null){
      onFailAdCallback = onFailAd;
    }
    if(onCloseAd != null){
      onCloseAdCallback = onCloseAd;
    }
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    switch (call.method) {
      case 'onLoadAd':
        if (onLoadAdCallback != null) {
          onLoadAdCallback();
        }
        break;
      case 'onShowAd':
        if (onShowAdCallback != null) {
          onShowAdCallback();
        }
        break;
      case 'onFailAd':
        String errorMessage = call.arguments.toString();
        if (onFailAdCallback != null) {
          onFailAdCallback(errorMessage);
        }
        break;
      case 'onCloseAd':
        if (onCloseAdCallback != null) {
          onCloseAdCallback();
        }
        break;
      default:
        throw ('method not defined');
    }
  }
}
